@@ -281,8 +281,8 @@ class TestAuth(wsgi.Middleware):
                         "from": "aalam/xxxx"}
 
 
-is_anonymous_user = lambda request: not request.auth or request.auth.get(
-    "email_id", None) == ANONYMOUS_EMAIL
+is_anonymous_user = lambda request: not request.auth or (request.auth.get(
+    "email_id", None) == ANONYMOUS_EMAIL) or is_auth_customer(request)
 
 
 def deny_anonymous_user(request):
