@@ -35,6 +35,14 @@ def get_common_rkey(rkey, redis_op='get'):
     return _globals[rkey]
 
 
+def _get_signature(message, privkey):
+    key = RSA.importKey(open(privkey).read())
+    h = SHA.new()
+    h.update(message)
+    signer = PKCS1_PSS.new(key)
+    return base64.b64encode(signer.sign(h)).decode('utf-8')
+
+
 def _sign_and_send(prefix, header_key, method, hostname, url,
                    scheme="http", **kwargs):
     if scheme == "http+unix":
@@ -73,12 +81,7 @@ def _sign_and_send(prefix, header_key, method, hostname, url,
         "scheme": scheme
     }
     # add auth header
-    key = RSA.importKey(open(cfg.CONF.privkey).read())
-    h = SHA.new()
-    h.update(message)
-    signer = PKCS1_PSS.new(key)
-    # signature = ''.join(signer.sign(h).encode("base64").split('\n'))
-    signature = base64.b64encode(signer.sign(h)).decode('utf-8')
+    signature = _get_signature(message, cfg.CONF.privkey)
     x_auth_signature = prefix + ";" + signature
 
     new_dict = {}
@@ -169,7 +172,7 @@ class DateTimeRFC7231(object):
 
     @staticmethod
     def decode(string):
-        return dt.strptime(string, DateTimeRFC7231.pattern)
+        return dt.datetime.strptime(string, DateTimeRFC7231.pattern)
 
 
 class datetime(object):
